@@ -1,3 +1,5 @@
+/*-*- Mode: C; c-basic-offset: 8 -*-*/
+
 #ifndef foocanberragtkhfoo
 #define foocanberragtkhfoo
 
@@ -22,11 +24,16 @@
 ***/
 
 #include <canberra.h>
+#include <gdk/gdk.h>
 #include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
+#ifndef GDK_MULTIHEAD_SAFE
 ca_context *ca_gtk_context_get(void);
+#endif
+
+ca_context *ca_gtk_context_get_for_screen(GdkScreen *screen);
 
 int ca_gtk_proplist_set_for_widget(ca_proplist *p, GtkWidget *w);
 
